#!/bin/sh

# Usage:
# `$0`: Ask for recording type via dmenu
# `$0 screencast`: Record both audio and screen
# `$0 video`: Record only screen
# `$0 audio`: Record only audio
# `$0 kill`: Kill existing recording
#
# If there is already a running instance, user will be prompted to end it.

RES=$(sed 's/,/x/g' /sys/class/graphics/fb?/virtual_size)

updateicon() { \
	echo "$1" > /tmp/recordingicon
	pkill -RTMIN+9 "${STATUSBAR:?}"
	}

killrecording() {
	recpid="$(cat /tmp/recordingpid)"
	# kill with SIGTERM, allowing finishing touches.
	kill -15 "$recpid"
	rm -f /tmp/recordingpid
	updateicon ""
	pkill -RTMIN+9 "${STATUSBAR:?}"
	# even after SIGTERM, ffmpeg may still run, so SIGKILL it.
	sleep 3
	kill -9 "$recpid"
	exit
	}

screencast() { \
	ffmpeg -y \
	-f x11grab \
	-framerate 24 \
	-s "$RES" \
	-i "$DISPLAY" \
	-f alsa -i default \
#	-f sndio -i snd/0 \
	-r 24 -async 1 -vsync -1 \
	-c:v libx264rgb -crf 0 -preset ultrafast -c:a aac \
 	-preset ultrafast -c:a libvorbis \
	"$HOME/screencast-$(date '+%y%m%d-%H%M%S').mkv" &
	echo $! > /tmp/recordingpid
	updateicon "⏺️🎙️"
       	}

screencastmobile() { \
	ffmpeg -y \
	-f x11grab \
	-framerate 60 \
	-s "$RES" \
	-i "$DISPLAY" \
	-f alsa -i default \
	-r 30 \
 	-c:v libx264 -profile:v baseline -level 3.0 -pix_fmt yuv420p -loglevel panic -c:a aac \
	"$HOME/screencast-$(date '+%y%m%d-%H%M%S').mp4" &
	echo $! > /tmp/recordingpid
	updateicon "⏺️🎙️"
       	}

video() { ffmpeg \
	-f x11grab \
	-s "$RES" \
	-i "$DISPLAY" \
 	-c:v libx264 -qp 0 -r 30 \
	"$HOME/video-$(date '+%y%m%d-%H%M%S').mkv" &
	echo $! > /tmp/recordingpid
	updateicon "⏺️"
	}

videomobile() { \
	ffmpeg -y \
	-f x11grab \
	-framerate 60 \
	-s "$RES" \
	-i "$DISPLAY" \
	-r 30 \
 	-c:v libx264 -profile:v baseline -level 3.0 -pix_fmt yuv420p -loglevel panic\
	"$HOME/video-$(date '+%y%m%d-%H%M%S').mp4" &
	echo $! > /tmp/recordingpid
	updateicon "⏺️🎙️"
       	}

webcamhidef() { ffmpeg \
	-f v4l2 \
	-i /dev/video0 \
	-video_size 1920x1080 \
	"$HOME/webcam-$(date '+%y%m%d-%H%M%S').mp4" &
	echo $! > /tmp/recordingpid
	updateicon "🎥"
	}

webcam() { ffmpeg \
	-f v4l2 \
	-i /dev/video0 \
	-video_size 640x480 \
	"$HOME/webcam-$(date '+%y%m%d-%H%M%S').mp4" &
	echo $! > /tmp/recordingpid
	updateicon "🎥"
	}

audio() { \
	ffmpeg \
	-f alsa -i default \
	-c:a flac \
	"$HOME/audio-$(date '+%y%m%d-%H%M%S').mp4" &
	echo $! > /tmp/recordingpid
	updateicon "🎙️"
	}

askrecording() { \
	choice=$(printf "screencast\\nwebcam\\nscreencastmobile\\nvideomobile" | dmenu -i -sb "#4D4270" -p "Seleccione el modo de grabación:")
	case "$choice" in
		screencast) screencast;;
		audio) audio;;
		video) video;;
		webcam) webcam;;
		screencastmobile) screencastmobile;;
                videomobile) videomobile;;
	esac
	}

asktoend() { \
	response=$(printf "No\\nSí" | dmenu -i -sb "#4D4270" -p "Grabación activa.¿Desea finalizar?") &&
	[ "$response" = "Sí" ] &&  killrecording
	}


case "$1" in
	screencast) screencast;;
	audio) audio;;
	video) video;;
	kill) killrecording;;
	*) ([ -f /tmp/recordingpid ] && asktoend && exit) || askrecording;;
esac
