#!/bin/sh
# Dependencias iproute, wpa_supplicant, dzen2, sudo, doas (opcional)
#
# Shell: POSIX compliant
# Autor: O. Sánchez <o-sanchez@linuxmail.org>

script="${0##*/}"

deps() {
if ! command -v wpa_supplicant; then
	printf '%b' "Dependencia no satisfecha:\n\twpa_supplicant\n"
	exit 1
elif ! command -v dzen2; then
	printf '%b' "Dependencia no satisfecha:\n\tdzen2\n"
	exit 1
fi
}


ayuda(){
printf %s "\
Script para establecer conexión a internet usando una dirección ip estática.

Uso: $script [interface]
 Ejemplo:
  $script eth0
  $script wlan0

"
}

admin() {
	if command -v sudo >/dev/null && sudo -l | grep -q -e ' ALL$' -e xbps-install; then
		echo sudo
	elif command -v doas >/dev/null && [ -f /etc/doas.conf ]; then
		echo doas
	elif [ "$(id -u)" != 0 ]; then
		echo su
	fi
}

msg() {
	dzen2 -p 5 -fn 'JetBrains Mono:size=8:style=bold' -ta 5 \
		-w 260 -x 1100 -y 25
}

SUDO=$(admin)

deps
case $1 in
	eth0)
		read -r state < /sys/class/net/"$1"/operstate
		if "$(pgrep wpa_supplicant)"; then
			"$SUDO" pkill -f wpa_supplicant
			if [ "$state" = "down" ]; then
				"$SUDO" ip link set "$1" up
				"$SUDO" ip a add 192.168.1.250/24 dev "$1"
				"$SUDO" ip route add default via 192.168.1.254 dev "$1"
				printf '%s\n' "Ethernet activado" | msg &
			fi
		elif [ "$state" = "down" ]; then
			"$SUDO" ip link set "$1" up
			"$SUDO" ip a add 192.168.1.250/24 dev "$1"
			"$SUDO" ip route add default via 192.168.1.254 dev "$1"
			printf '%s\n' "Ethernet activado" | msg &
		elif [  "$state" = "up" ]; then
			"$SUDO" ip link set eth0 down
			printf '%s\n' "Ethernet desactivado" | msg &
		fi
		;;
	wlan0)
		read -r state < /sys/class/net/"$1"/operstate
		read -r ethernet < /sys/class/net/eth0/operstate
		if [ "$ethernet" = "up" ]; then
			"$SUDO" ip link set eth0 down
			"$SUDO" ip a add 192.168.1.245/24 dev "$1"
			"$SUDO" ip route add default via 192.168.1.254 dev "$1"
			"$SUDO" wpa_supplicant -B -D nl80211,wext -c /etc/wpa_supplicant/wpa_supplicant-wlan0.conf -i "$1"
			printf '%s\n' "Wifi activado" | msg &
		elif [ "$state" = "down" ]; then
			"$SUDO" ip link set "$1" up
			"$SUDO" ip a add 192.168.1.245/24 dev "$1"
			"$SUDO" ip route add default via 192.168.1.254 dev "$1"
			"$SUDO" wpa_supplicant -B -D nl80211,wext -c /etc/wpa_supplicant/wpa_supplicant-wlan0.conf -i "$1"
			printf '%s\n' "Wifi activado" | msg &
		elif [ "$(pgrep wpa_supplicant)" ]; then
			"$SUDO" pkill -f wpa_supplicant
			"$SUDO" ip link set wlan0 down
			printf '%s\n' "Wifi desactivado" | msg &
		fi
		;;
	--help|-h|*)
		ayuda
esac
